@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2013 DNAnexus, Inc.
+# Copyright (C) 2013-2014 DNAnexus, Inc.
 #
 # This file is part of dx-toolkit (DNAnexus platform client libraries).
 #
@@ -17,37 +17,41 @@
 #   License for the specific language governing permissions and limitations
 #   under the License.
 
-from __future__ import print_function
+from __future__ import print_function, unicode_literals
 
 import os, sys, unittest, json, tempfile, subprocess
 import pexpect
 
-from dxpy_testutil import DXTestCase
+from dxpy_testutil import DXTestCase, check_output
 import dxpy_testutil as testutil
 
 import dxpy
 from dxpy.scripts import dx_build_app
+from dxpy.exceptions import DXCLIError
 
 supported_languages = ['Python', 'C++', 'bash']
 
 def run_dx_app_wizard():
     old_cwd = os.getcwd()
-    tempdir = tempfile.mkdtemp()
+    tempdir = tempfile.mkdtemp(prefix='Программа')
     os.chdir(tempdir)
     try:
         wizard = pexpect.spawn("dx-app-wizard")
         wizard.logfile = sys.stdout
         wizard.setwinsize(20, 90)
         wizard.expect("App Name:")
+        wizard.sendline("Имя")
+        wizard.expect("The name of your app must match")
+        wizard.expect("App Name:")
         wizard.sendline("MyTestApp")
         wizard.expect("Title")
-        wizard.sendline()
+        wizard.sendline("Заголовок")
         wizard.expect("Summary")
-        wizard.sendline()
+        wizard.sendline("Конспект")
         wizard.expect("Description")
-        wizard.sendline()
+        wizard.sendline("Описание")
         wizard.expect("Version")
-        wizard.sendline()
+        wizard.sendline("1.2.3")
         wizard.expect("Choose a category")
         wizard.sendline("Assembly")
         wizard.expect("Choose a category")
@@ -55,7 +59,7 @@ def run_dx_app_wizard():
         wizard.expect("1st input name")
         wizard.sendline("in1")
         wizard.expect("Label")
-        wizard.sendline()
+        wizard.sendline("Метка")
         wizard.expect("Choose a class")
         wizard.sendline("int")
         wizard.expect("optional parameter")
@@ -67,12 +71,19 @@ def run_dx_app_wizard():
         wizard.expect("Label")
         wizard.sendline()
         wizard.expect("Choose a class")
+        wizard.sendline("целое")
+        wizard.expect("Not a recognized class")
         wizard.sendline("int")
         wizard.expect("2nd output name")
         wizard.sendline()
         wizard.expect("Programming language")
+        wizard.sendline("АЛГОЛ")
+        wizard.expect("Error: unrecognized response")
         wizard.sendline("Python")
         wizard.expect("Execution pattern")
+        wizard.sendline("параллельно")
+        wizard.expect("Error: unrecognized response")
+        wizard.expect("Execution pattern")
         wizard.sendline("parallelized")
         wizard.expect("Will this app need access to the Internet?")
         wizard.sendline("y")
@@ -142,7 +153,7 @@ class TestDXAppWizardAndRunAppLocally(DXTestCase):
 
     def test_dx_run_app_locally(self):
         appdir = create_app_dir()
-        output = subprocess.check_output(['dx-run-app-locally', appdir, '-iin1=8'])
+        output = check_output(['dx-run-app-locally', appdir, '-iin1=8'])
         print(output)
         self.assertIn("App finished successfully", output)
         self.assertIn("Final output: out1 = 140", output)
@@ -339,5 +350,59 @@ class TestDXAppWizardAndRunAppLocally(DXTestCase):
                 subprocess.check_output(['dx', 'build', appdir, '--destination', applet_name])
                 subprocess.check_output(['dx', 'run', applet_name, '-y', '--wait'] + cmdline_args)
 
+'''
+test the upload/download helpers by running them locally
+'''
+class TestDXBashHelpers(DXTestCase):
+    def run_test_app_locally(self, app_name, arg_list):
+        '''
+        :param app_name: name of app to run
+        :param arg_list: list of command line arguments given to an app
+
+        Runs an app locally, with a given set of command line arguments
+        '''
+        path = os.path.join(os.path.dirname(__file__), "file_load")
+        args = ['dx-run-app-locally', os.path.join(path, app_name)]
+        args.extend(arg_list)
+        check_output(args)
+
+    def test_basic(self):
+        # Make a couple files for testing
+        print("testing upload/download helpers")
+        dxpy.upload_string("1234", name="A.txt")
+
+        # this invocation should fail with a CLI exception
+        with self.assertRaises(testutil.DXCalledProcessError):
+            self.run_test_app_locally('basic', ['-iseq1=A.txt', '-iseq2=B.txt'])
+
+        dxpy.upload_string("ABCD", name="B.txt")
+
+        # these should succeed
+        self.run_test_app_locally('basic',['-iseq1=A.txt', '-iseq2=B.txt',
+                                           '-iref=A.txt', '-iref=B.txt',
+                                           "-ivalue=5", '-iages=1'])
+        self.run_test_app_locally('basic',['-iseq1=A.txt', '-iseq2=B.txt', '-ibar=A.txt',
+                                           '-iref=A.txt', '-iref=B.txt',
+                                           "-ivalue=5", '-iages=1'])
+        self.run_test_app_locally('basic', ['-iseq1=A.txt', '-iseq2=B.txt',
+                                            '-iref=A.txt', '-iref=B.txt', "-ivalue=5",
+                                            '-iages=1', '-iages=11', '-iages=33'])
+        print("Done")
+
+    def test_sub_jobs(self):
+        '''  Tests a bash script that generates sub-jobs '''
+        dxpy.upload_string("1234", name="A.txt")
+        dxpy.upload_string("ABCD", name="B.txt")
+        self.run_test_app_locally('with-subjobs', ["-ifiles=A.txt", "-ifiles=B.txt"])
+
+    def test_name_collision(self):
+        '''  Tests that name collisions are handled correctly. This is supposed to fail.'''
+        dxpy.upload_string("1234", name="A.txt")
+        with self.assertRaises(testutil.DXCalledProcessError):
+            self.run_test_app_locally('basic', ["-iseq1=A.txt", "-iseq2=A.txt",
+                                                '-iref=A.txt', '-iref=A.txt',
+                                                "-ivalue=5"])
+
+
 if __name__ == '__main__':
     unittest.main()
